@@ -11,7 +11,7 @@
 
 use std::ffi::c_void;
 
-use crate::{NcIntResult, NcPlane, NcTime, Notcurses};
+use crate::{c_api, Nc, NcIntResult, NcPlane, NcTime};
 
 /// Called for each fade iteration on the NcPlane.
 ///
@@ -19,9 +19,8 @@ use crate::{NcIntResult, NcPlane, NcTime, Notcurses};
 /// and that value is propagated out.
 ///
 /// The recommended absolute display time target is passed in 'tspec'.
-pub type NcFadeCb = Option<
-    unsafe extern "C" fn(*mut Notcurses, *mut NcPlane, *const NcTime, *mut c_void) -> NcIntResult,
->;
+pub type NcFadeCb =
+    Option<unsafe extern "C" fn(*mut Nc, *mut NcPlane, *const NcTime, *mut c_void) -> NcIntResult>;
 
 /// Context for a palette fade operation
 pub type NcFadeCtx = crate::bindings::ffi::ncfadectx;
@@ -33,18 +32,18 @@ impl NcFadeCtx {
     /// ncfadectx_setup() can be paired with a loop over
     /// ncplane_fade{in/out}_iteration() + ncfadectx_free().
     pub fn setup(plane: &mut NcPlane) -> &mut NcFadeCtx {
-        unsafe { &mut *crate::ncfadectx_setup(plane) }
+        unsafe { &mut *c_api::ncfadectx_setup(plane) }
     }
 
     /// Releases the resources associated.
     pub fn free(&mut self) {
         unsafe {
-            crate::ncfadectx_free(self);
+            c_api::ncfadectx_free(self);
         }
     }
 
     /// Returns the number of iterations through which will fade.
     pub fn iterations(&self) -> u32 {
-        unsafe { crate::ncfadectx_iterations(self) as u32 }
+        unsafe { c_api::ncfadectx_iterations(self) as u32 }
     }
 }
