@@ -3,9 +3,11 @@
 //
 // NOTE: Use full paths everywhere. Don't assume anything will be in scope.
 
-#[allow(unused_imports)]
-// enjoy briefer doc comments
-use crate::{Nc, NcDirect, NcError, NcPlane, NcResult, NCRESULT_ERR, NCRESULT_OK};
+#[allow(unused_imports)] // for doc comments
+use crate::{
+    c_api::{NCRESULT_ERR, NCRESULT_OK},
+    Nc, NcDirect, NcError, NcIntResultApi, NcPlane, NcResult, NcVisual, NcVisualOptions,
+};
 
 // Sleep, Render & Flush Macros ------------------------------------------------
 
@@ -32,15 +34,34 @@ macro_rules! sleep {
     };
 }
 
-/// notcurses render sleep:
+#[doc(hidden)]
+#[macro_export]
+#[deprecated]
+#[allow(unused_macros)]
+macro_rules! nrs {
+    ($($rest:tt)*) => {
+        nc_render_sleep!($($rest)*)
+    }
+}
+
+#[doc(hidden)]
+#[macro_export]
+#[deprecated]
+#[allow(unused_macros)]
+macro_rules! prs {
+    ($($rest:tt)*) => {
+        pile_render_sleep!($($rest)*)
+    }
+}
+
 /// [`Nc::render`][Nc#method.render]\(`$nc`\)? + [`sleep!`]`[$sleep_args]`.
 ///
-/// Renders the `$nc` [`Nc`] object's standard plane pile and then,
-/// if there's no error, calls the sleep macro with the rest of the arguments.
+/// Renders the `$nc` [`Nc`]'s standard pile, and then,
+/// if there's no error, calls the `sleep` macro with the rest of the arguments.
 ///
-/// Returns [NcResult].
+/// Returns [`NcResult`].
 #[macro_export]
-macro_rules! nrs {
+macro_rules! nc_render_sleep {
     ($nc:expr, $( $sleep_args:expr),+ ) => {
         crate::Nc::render($nc)?;
         sleep![$( $sleep_args ),+];
@@ -50,17 +71,16 @@ macro_rules! nrs {
     };
 }
 
-/// plane render sleep:
 /// [`NcPlane::render`][NcPlane#method.render]\(`$p`\)? +
 /// [`NcPlane::rasterize`][NcPlane#method.rasterize]\(`$p`\)? +
 /// [`sleep!`]`[$sleep_args]`.
 ///
-/// Renders and rasterizes the `$p` [NcPlane] pile and then, if there are
-/// no errors, calls the sleep macro with the rest of the arguments.  
+/// Renders and rasterizes the `$p` [`NcPlane`] pile and then, if there are
+/// no errors, calls the sleep macro with the rest of the arguments.
 ///
-/// Returns [NcResult].
+/// Returns [`NcResult`].
 #[macro_export]
-macro_rules! prs {
+macro_rules! pile_render_sleep {
     ($p:expr, $( $sleep_args:expr),+ ) => {
         crate::NcPlane::render($p)?;
         crate::NcPlane::rasterize($p)?;
@@ -71,6 +91,26 @@ macro_rules! prs {
     };
 }
 
+/// [`NcVisual::blit`][NcVisual#method.blit]\(`$v`, `$nc`, `$vo`\)? +
+/// [`Nc::render`][Nc#method.render]\(`$nc`\)? + [`sleep!`]`[$sleep_args]`.
+///
+/// Renders and rasterizes the `$v` [`NcVisual`] with its `$vo`
+/// [`NcVisualOptions`], the $nc` [`Nc`]'s standard pile, and then, if there are
+/// no errors, calls the `sleep` macro with the rest of the arguments.
+///
+/// Returns [`NcResult`].
+#[macro_export]
+macro_rules! visual_render_sleep {
+    ($v: expr, $vo: expr, $nc:expr, $( $sleep_args:expr),+ ) => {
+        crate::NcVisual::blit($v, $nc, Some($vo))?;
+        crate::Nc::render($nc)?;
+        sleep![$( $sleep_args ),+];
+    };
+    ($nc:expr, $( $sleep_args:expr),+ ,) => {
+        rsleep![$nc, $( $sleep_args ),* ]
+    };
+}
+
 /// [`NcDirect::flush`][NcDirect#method.flush]\(`$ncd`\)? + [`sleep!`]`[$sleep_args]`.
 ///
 /// Flushes the `$ncd` [NcDirect] object and, if there's no error,
@@ -121,6 +161,8 @@ macro_rules! rsleep {
 // String & Print Macros -------------------------------------------------------
 
 /// Converts an `&str` into `*const c_char`.
+///
+/// See [`Cstring`].
 #[macro_export]
 #[doc(hidden)]
 macro_rules! cstring {
@@ -130,11 +172,17 @@ macro_rules! cstring {
 }
 
 /// Converts an `&str` into `*mut c_char`.
+///
+/// See [`Cstring`].
 #[macro_export]
 #[doc(hidden)]
 macro_rules! cstring_mut {
     ($s:expr) => {
+        // we can't use this without taking the responsibility of deallocating:
         std::ffi::CString::new($s).unwrap().into_raw()
+
+        // another option:
+        // unsafe { crate::c_api::libc::strdup(crate::cstring![$s]) }
     };
 }
 
@@ -157,20 +205,107 @@ macro_rules! rstring_free {
         #[allow(unused_unsafe)]
         let nc_string = unsafe { $s };
         let string = crate::rstring![nc_string].to_string();
-        unsafe { libc::free(nc_string as *mut core::ffi::c_void) };
+        unsafe { crate::c_api::libc::free(nc_string as *mut core::ffi::c_void) };
         string
     }};
 }
 
-/// Wrapper around [libc::printf].
+/// Wrapper around [`libc::printf`][c_api::libc::printf].
 #[macro_export]
 #[doc(hidden)]
 macro_rules! printf {
     ($s:expr) => {
-        unsafe { libc::printf(cstring![$s]) }
+        unsafe { crate::c_api::libc::printf(cstring![$s]) }
     };
     ($s:expr $(, $opt:expr)*) => {
-        unsafe { libc::printf(cstring![$s], $($opt),*) }
+        unsafe { crate::c_api::libc::printf(cstring![$s], $($opt),*) }
+    };
+}
+
+/// Wrapper around [`NcPlane.putstr`][NcPlane#method.putstr],
+/// rendering and rasterizing the plane afterwards.
+///
+/// Returns an `NcResult` with the number of columns advanced,
+/// without including newlines.
+///
+/// # Example
+/// ```
+/// # use libnotcurses_sys::*;
+/// # fn main() -> NcResult<()> {
+/// let nc = Nc::new_cli()?;
+/// let splane = nc.stdplane();
+/// splane.set_scrolling(true);
+/// putstr!(splane, "hello ")?;
+/// putstr!(splane, " world\n")?;
+/// putstr!(splane, "formatted text: {:?}\n", (0, 1.0, "two") )?;
+/// # nc.stop()?;
+/// # Ok(())
+/// # }
+/// ```
+#[macro_export]
+macro_rules! putstr {
+    ($plane:ident, $text:literal) => {
+        {
+            let res = $plane.putstr($text)?;
+            $plane.render()?;
+            $plane.rasterize()?;
+            Ok(res)
+        }
+    };
+    ($plane:ident, $text:literal, $($args:tt)*) => {
+        {
+            let res = $plane.putstr(&format![$text, $($args)*])?;
+            $plane.render()?;
+            $plane.rasterize()?;
+            Ok(res)
+        }
+    };
+}
+
+/// Wrapper around [`NcPlane.putstrln`][NcPlane#method.putstrln].
+/// rendering and rasterizing the plane afterwards.
+///
+/// Returns an `NcResult` with the number of columns advanced,
+/// without including newlines.
+///
+/// # Example
+/// ```ignore
+/// # use libnotcurses_sys::*;
+/// # fn main() -> NcResult<()> {
+/// let nc = Nc::new_cli()?;
+/// let splane = nc.stdplane();
+/// splane.set_scrolling(true);
+/// putstrln!(splane, "hello world")?;
+/// putstrln!(splane, "formatted text: {:?}", (0, 1.0, "two") )?;
+/// # nc.stop()?;
+/// # Ok(())
+/// # }
+/// ```
+#[macro_export]
+macro_rules! putstrln {
+    ($plane:ident) => {
+        {
+            let res = $plane.putln()?;
+            $plane.render()?;
+            $plane.rasterize()?;
+            Ok(res)
+        }
+    };
+    ($plane:ident, $text:literal) => {
+        {
+            let res = $plane.putstrln($text)?;
+            $plane.render()?;
+            $plane.rasterize()?;
+            Ok(res)
+        }
+    };
+    ($plane:ident, $text:literal, $($args:tt)*) => {
+        {
+            let res = $plane.putstrln(&format![$text, $($args)*])?;
+            $plane.render()?;
+            $plane.rasterize()?;
+            Ok(res)
+        }
     };
 }
 
@@ -190,7 +325,7 @@ macro_rules! printf {
 macro_rules! error {
     ($res:expr, $msg:expr, $ok:expr) => {{
         let res = $res;
-        if res >= crate::NCRESULT_OK {
+        if res >= crate::c_api::NCRESULT_OK {
             return Ok($ok);
         } else {
             return Err(crate::NcError::with_msg(res, $msg));
@@ -218,7 +353,7 @@ macro_rules! error_ref {
     ($ptr:expr, $msg:expr, $ok:expr) => {{
         let ptr = $ptr; // avoid calling a function multiple times
         if ptr.is_null() {
-            return Err(crate::NcError::with_msg(crate::NCRESULT_ERR, $msg));
+            return Err(crate::NcError::with_msg(crate::c_api::NCRESULT_ERR, $msg));
         } else {
             #[allow(unused_unsafe)]
             return Ok(unsafe { $ok });
@@ -248,7 +383,7 @@ macro_rules! error_ref_mut {
     ($ptr:expr, $msg:expr, $ok:expr) => {{
         let ptr = $ptr; // avoid calling a function multiple times
         if ptr.is_null() {
-            return Err(crate::NcError::with_msg(crate::NCRESULT_ERR, $msg));
+            return Err(crate::NcError::with_msg(crate::c_api::NCRESULT_ERR, $msg));
         } else {
             #[allow(unused_unsafe)]
             return Ok(unsafe { $ok });
@@ -278,12 +413,33 @@ macro_rules! error_str {
     ($str:expr, $msg:expr) => {
         if !$str.is_null() {
             #[allow(unused_unsafe)]
-            return Ok(unsafe { (&*$str).to_string() });
+            return Ok(unsafe { crate::rstring!($str).to_string() });
         } else {
-            return Err(crate::NcError::with_msg(crate::NCRESULT_ERR, $msg));
+            return Err(crate::NcError::with_msg(crate::c_api::NCRESULT_ERR, $msg));
         }
     };
     ($str:expr) => {
         error_str![$str, ""];
     };
 }
+
+// Implementation Helper Macros ------------------------------------------------
+
+/// Implements methods and constants for an existing type.
+//
+// Allows to have full doc-comments both in the trait definition
+// and in the concrete implementation.
+#[macro_export]
+#[doc(hidden)]
+macro_rules! impl_api {
+    ($type:ident, $trait:ident, $($i:item),*) => {
+        #[doc = concat!("Enables the [`", stringify!($type), "`] associated methods and constants.")]
+        pub trait $trait {
+            $($i)*
+        }
+
+        impl $trait for $type {
+            $($i)*
+        }
+    };
+}
