@@ -1,9 +1,9 @@
 //! `NcPlane`
 
-// functions already exported by bindgen : 103
+// functions already exported by bindgen : 101
 // -------------------------------------------
 // (#) test: 9
-// (W) wrap: 95
+// (W) wrap: 93
 // -------------------------------------------
 //W  ncpile_bottom
 //W# ncpile_create
@@ -49,10 +49,8 @@
 //W  ncplane_mergedown_simple
 //W  ncplane_move_above
 //W  ncplane_move_below
-//W  ncplane_move_bottom
 //W  ncplane_move_family_above
 //W  ncplane_move_family_below
-//W  ncplane_move_top
 //W  ncplane_move_yx
 //W# ncplane_notcurses
 //W# ncplane_notcurses_const
@@ -109,10 +107,10 @@
 //W  ncplane_y
 //W  ncplane_yx
 
-// functions manually reimplemented: 43
+// functions manually reimplemented: 45
 // ------------------------------------------
-// (+) done: 43
-// (W) wrap: 39
+// (+) done: 45
+// (W) wrap: 41
 // (#) test:  9
 // ------------------------------------------
 //W+ ncplane_bchannel
@@ -136,8 +134,10 @@
 //W+ ncplane_halign
 // + ncplane_hline
 //W+ ncplane_moverel
+//W+ ncplane_move_bottom
 //W+ ncplane_move_family_bottom
 //W+ ncplane_move_family_top
+//W+ ncplane_move_top
 //W+ ncplane_perimeter
 //W+ ncplane_perimeter_double
 //W+ ncplane_perimeter_rounded
@@ -182,16 +182,13 @@
 //   ncplane_putwstr_yx
 //   ncplane_vprintf
 
-#[cfg(test)]
-mod test;
-
-mod helpers;
 mod methods;
-mod reimplemented;
 
-#[allow(unused_imports)]
-pub(crate) use helpers::*;
-pub use reimplemented::*;
+pub(crate) mod helpers;
+pub(crate) mod reimplemented;
+
+#[cfg(test)]
+pub(crate) mod test;
 
 // NcPlane
 /// Fundamental drawing surface.
@@ -266,7 +263,7 @@ pub use reimplemented::*;
 /// - [Constructors & Destructors](#ncplane-constructors--destructors)
 ///
 /// Methods:
-/// - [`NcAlphaBits`](#ncplane-methods-ncalphabits)
+/// - [`NcAlpha`](#ncplane-methods-ncalphabits)
 /// - [`NcChannel` & `NcChannels`](#ncplane-methods-ncchannel)
 /// - [`NcComponent`, `NcRgb` & default color](#ncplane-methods-nccomponent-ncrgb--default-color)
 /// - [`NcStyle` & `NcPaletteIndex`](#ncplane-methods-ncstylemask--paletteindex)
@@ -282,18 +279,39 @@ pub type NcPlane = crate::bindings::ffi::ncplane;
 /// Options struct for [`NcPlane`]
 pub type NcPlaneOptions = crate::bindings::ffi::ncplane_options;
 
-/// Horizontal alignment relative to the parent plane. Use NcAlign for 'x'.
-pub const NCPLANE_OPTION_HORALIGNED: u64 = crate::bindings::ffi::NCPLANE_OPTION_HORALIGNED as u64;
+impl NcPlaneOptions {
+    /// Horizontal alignment relative to the parent plane. Use NcAlign for 'x'.
+    pub const HORALIGNED: u64 = constants::NCPLANE_OPTION_HORALIGNED as u64;
 
-/// Vertical alignment relative to the parent plane. Use NcAlign for 'y'.
-pub const NCPLANE_OPTION_VERALIGNED: u64 = crate::bindings::ffi::NCPLANE_OPTION_VERALIGNED as u64;
+    /// Vertical alignment relative to the parent plane. Use NcAlign for 'y'.
+    pub const VERALIGNED: u64 = constants::NCPLANE_OPTION_VERALIGNED as u64;
 
-/// Maximize relative to the parent plane, modulo the provided margins.
-///
-/// The margins are best-effort; the plane will always be at least 1 column by
-/// 1 row. If the margins can be effected, the plane will be sized to all
-/// remaining space. 'y' and 'x' are overloaded as the top and left margins
-/// when this flag is used. 'rows' and 'cols' must be 0 when this flag is
-/// used. This flag is exclusive with both of the alignment flags.
-pub const NCPLANE_OPTION_MARGINALIZED: u64 =
-    crate::bindings::ffi::NCPLANE_OPTION_MARGINALIZED as u64;
+    /// Maximize relative to the parent plane, modulo the provided margins.
+    ///
+    /// The margins are best-effort; the plane will always be at least 1 column by
+    /// 1 row. If the margins can be effected, the plane will be sized to all
+    /// remaining space. 'y' and 'x' are overloaded as the top and left margins
+    /// when this flag is used. 'rows' and 'cols' must be 0 when this flag is
+    /// used. This flag is exclusive with both of the alignment flags.
+    pub const MARGINALIZED: u64 = constants::NCPLANE_OPTION_MARGINALIZED as u64;
+}
+
+pub(crate) mod constants {
+    /// Horizontal alignment relative to the parent plane. Use NcAlign for 'x'.
+    pub const NCPLANE_OPTION_HORALIGNED: u64 =
+        crate::bindings::ffi::NCPLANE_OPTION_HORALIGNED as u64;
+
+    /// Vertical alignment relative to the parent plane. Use NcAlign for 'y'.
+    pub const NCPLANE_OPTION_VERALIGNED: u64 =
+        crate::bindings::ffi::NCPLANE_OPTION_VERALIGNED as u64;
+
+    /// Maximize relative to the parent plane, modulo the provided margins.
+    ///
+    /// The margins are best-effort; the plane will always be at least 1 column by
+    /// 1 row. If the margins can be effected, the plane will be sized to all
+    /// remaining space. 'y' and 'x' are overloaded as the top and left margins
+    /// when this flag is used. 'rows' and 'cols' must be 0 when this flag is
+    /// used. This flag is exclusive with both of the alignment flags.
+    pub const NCPLANE_OPTION_MARGINALIZED: u64 =
+        crate::bindings::ffi::NCPLANE_OPTION_MARGINALIZED as u64;
+}
