@@ -1,17 +1,15 @@
 //! `NcVisual*` methods and associated functions.
 
-use core::ptr::null_mut;
+use core::ptr::{null, null_mut};
 use libc::c_void;
 
 use crate::{
-    cstring, error, error_ref_mut, rstring_free, Nc, NcBlitter, NcBlitterGeometry, NcChannel,
-    NcComponent, NcDim, NcDirect, NcDirectF, NcError, NcIntResult, NcPixel, NcPlane, NcResult,
-    NcRgba, NcScale, NcTime, NcVGeom, NcVisual, NcVisualOptions, NCBLIT_PIXEL, NCRESULT_ERR,
+    c_api, cstring, error, error_ref_mut, rstring_free, Nc, NcBlitter, NcBlitterApi,
+    NcBlitterGeometry, NcChannel, NcComponent, NcDim, NcDirect, NcError, NcIntResult,
+    NcIntResultApi, NcPixel, NcPlane, NcResult, NcRgba, NcScale, NcTime, NcVGeom, NcVisual,
+    NcVisualOptions,
 };
 
-#[allow(unused_imports)]
-use crate::{NCBLIT_1x1, NCBLIT_2x1, NCBLIT_2x2, NCBLIT_3x2, NCSCALE_STRETCH};
-
 /// # NcVisualOptions Constructors
 impl NcVisualOptions {
     // /// New NcVisualOptions
@@ -31,9 +29,9 @@ impl NcVisualOptions {
 
     /// Specify an existing plane.
     ///
-    /// If [`NCVISUAL_OPTION_CHILDPLANE`][crate::NCVISUAL_OPTION_CHILDPLANE] is
-    /// used in `flags` then the `plane` is interpreted as the parent [`NcPlane`]
-    /// of the new plane created for this [`NcVisual`].
+    /// If [`NcVisualOptions::CHILDPLANE`][NcVisualOptions#associatedconstant.CHILDPLANE]
+    /// is used in `flags` then the `plane` is interpreted as the parent
+    /// [`NcPlane`] of the new plane created for this [`NcVisual`].
     pub fn with_plane(
         plane: &mut NcPlane,
         scale: NcScale,
@@ -43,6 +41,8 @@ impl NcVisualOptions {
         beg_x: NcDim,
         len_y: NcDim,
         len_x: NcDim,
+        // pxoff_y: NcDim,
+        // pxoff_x: NcDim,
         blitter: NcBlitter,
         flags: u32,
         transcolor: NcRgba,
@@ -65,9 +65,13 @@ impl NcVisualOptions {
             // bitmask over NCVISUAL_OPTION_*
             flags: flags as u64,
             transcolor,
+            // WIP
+            pxoffy: 0,
+            pxoffx: 0,
         }
     }
 
+    // TODO: use Option<> groups for coords
     pub fn without_plane(
         y: NcDim,
         x: NcDim,
@@ -75,14 +79,16 @@ impl NcVisualOptions {
         beg_x: NcDim,
         len_y: NcDim,
         len_x: NcDim,
+        // pxoff_y: NcDim,
+        // pxoff_x: NcDim,
         blitter: NcBlitter,
         flags: u32,
         transcolor: u32,
     ) -> Self {
         Self {
             n: null_mut(),
-            scaling: crate::NCSCALE_NONE,
-            // where the created ncplane will be placed relative to the standard plane's origin
+            scaling: crate::c_api::NCSCALE_NONE,
+            // where the created plane will be placed relative to stdplane's origin
             y: y as i32,
             x: x as i32,
             // origin of rendered section
@@ -97,11 +103,22 @@ impl NcVisualOptions {
             flags: flags as u64,
             // This color will be treated as transparent with flag [NCVISUAL_OPTION_ADDALPHA].
             transcolor,
+            // pixel offsets within the cell.
+            // if NCBLIT_PIXEL is used, the bitmap will be drawn offset from the
+            // upper-left cell's origin by these amounts. it is an error if
+            // either number exceeds the cell-pixel geometry in its dimension.
+            // if NCBLIT_PIXEL is not used, these fields are ignored.
+            // this functionality can be used for smooth bitmap movement.
+            // WIP
+            pxoffy: 0,
+            pxoffx: 0,
+            // pxoffy: pxoff_y,
+            // pxoffx: pxoff_x,
         }
     }
 
     pub fn fullsize_pixel_without_plane(y: NcDim, x: NcDim, len_y: NcDim, len_x: NcDim) -> Self {
-        Self::without_plane(y, x, 0, 0, len_y, len_x, NCBLIT_PIXEL, 0, 0)
+        Self::without_plane(y, x, 0, 0, len_y, len_x, NcBlitter::PIXEL, 0, 0)
     }
 }
 
@@ -109,7 +126,7 @@ impl NcVisualOptions {
 impl NcVisual {
     /// Like [from_rgba][NcVisual#method.from_rgba], but 'bgra' is arranged as BGRA.
     ///
-    /// *C style function: [ncvisual_from_bgra()][crate::ncvisual_from_bgra].*
+    /// *C style function: [ncvisual_from_bgra()][c_api::ncvisual_from_bgra].*
     pub fn from_bgra<'a>(
         bgra: &[u8],
         rows: NcDim,
@@ -118,7 +135,7 @@ impl NcVisual {
     ) -> NcResult<&'a mut NcVisual> {
         error_ref_mut![
             unsafe {
-                crate::ncvisual_from_bgra(
+                c_api::ncvisual_from_bgra(
                     bgra.as_ptr() as *const c_void,
                     rows as i32,
                     rowstride as i32,
@@ -135,10 +152,10 @@ impl NcVisual {
     /// Opens a visual at `file`, extracts the codec and parameters and
     /// decodes the first image to memory.
     ///
-    /// *C style function: [ncvisual_from_file()][crate::ncvisual_from_file].*
+    /// *C style function: [ncvisual_from_file()][c_api::ncvisual_from_file].*
     pub fn from_file<'a>(file: &str) -> NcResult<&'a mut NcVisual> {
         error_ref_mut![
-            unsafe { crate::ncvisual_from_file(cstring![file]) },
+            unsafe { c_api::ncvisual_from_file(cstring![file]) },
             &format!("NcVisual::from_file({})", file)
         ]
     }
@@ -152,7 +169,7 @@ impl NcVisual {
     /// If possible, it's better to create the ncvisual from memory using
     /// [from_rgba][NcVisual#method.from_rgba].
     ///
-    /// *C style function: [ncvisual_from_plane()][crate::ncvisual_from_plane].*
+    /// *C style function: [ncvisual_from_plane()][c_api::ncvisual_from_plane].*
     pub fn from_plane<'a>(
         plane: &NcPlane,
         blitter: NcBlitter,
@@ -163,7 +180,7 @@ impl NcVisual {
     ) -> NcResult<&'a mut NcVisual> {
         error_ref_mut![
             unsafe {
-                crate::ncvisual_from_plane(
+                c_api::ncvisual_from_plane(
                     plane,
                     blitter,
                     beg_y as i32,
@@ -184,7 +201,7 @@ impl NcVisual {
     ///
     /// `rowstride` must be a multiple of 4.
     ///
-    /// *C style function: [ncvisual_from_rgb_loose()][crate::ncvisual_from_rgb_loose].*
+    /// *C style function: [ncvisual_from_rgb_loose()][c_api::ncvisual_from_rgb_loose].*
     pub fn from_rgb_loose<'a>(
         rgb: &[u8],
         rows: NcDim,
@@ -194,7 +211,7 @@ impl NcVisual {
     ) -> NcResult<&'a mut NcVisual> {
         error_ref_mut![
             unsafe {
-                crate::ncvisual_from_rgb_loose(
+                c_api::ncvisual_from_rgb_loose(
                     rgb.as_ptr() as *const c_void,
                     rows as i32,
                     rowstride as i32,
@@ -212,7 +229,7 @@ impl NcVisual {
     /// Like [`from_rgba`][NcVisual#method.from_rgba], but the pixels are
     /// 3-byte RGB. Alpha is filled in throughout using 'alpha'.
     ///
-    /// *C style function: [ncvisual_from_rgb_packed()][crate::ncvisual_from_rgb_packed].*
+    /// *C style function: [ncvisual_from_rgb_packed()][c_api::ncvisual_from_rgb_packed].*
     pub fn from_rgb_packed<'a>(
         rgb: &[u8],
         rows: NcDim,
@@ -222,7 +239,7 @@ impl NcVisual {
     ) -> NcResult<&'a mut NcVisual> {
         error_ref_mut![
             unsafe {
-                crate::ncvisual_from_rgb_packed(
+                c_api::ncvisual_from_rgb_packed(
                     rgb.as_ptr() as *const c_void,
                     rows as i32,
                     rowstride as i32,
@@ -247,7 +264,7 @@ impl NcVisual {
     /// The total size of `rgba` is thus (rows * rowstride) bytes, of which
     /// (rows * cols * 4) bytes are actual non-padding data.
     ///
-    /// *C style function: [ncvisual_from_rgba()][crate::ncvisual_from_rgba].*
+    /// *C style function: [ncvisual_from_rgba()][c_api::ncvisual_from_rgba].*
     pub fn from_rgba<'a>(
         rgba: &[u8],
         rows: NcDim,
@@ -256,7 +273,7 @@ impl NcVisual {
     ) -> NcResult<&'a mut NcVisual> {
         error_ref_mut![
             unsafe {
-                crate::ncvisual_from_rgba(
+                c_api::ncvisual_from_rgba(
                     rgba.as_ptr() as *const c_void,
                     rows as i32,
                     rowstride as i32,
@@ -276,7 +293,7 @@ impl NcVisual {
     ///
     /// `palette` is an array of at least `palsize` [`NcChannel`]s.
     ///
-    /// *C style function: [ncvisual_from_palidx()][crate::ncvisual_from_palidx].*
+    /// *C style function: [ncvisual_from_palidx()][c_api::ncvisual_from_palidx].*
     //
     // API ALLOC struct ncvisual* ncvisual_from_palidx(const void* data, int rows,
     // int rowstride, int cols, int palsize, int pstride, const uint32_t* palette)
@@ -301,7 +318,7 @@ impl NcVisual {
         // assert![];
         error_ref_mut![
             unsafe {
-                crate::ncvisual_from_palidx(
+                c_api::ncvisual_from_palidx(
                     data.as_ptr() as *const c_void,
                     rows as i32,
                     rowstride as i32,
@@ -323,9 +340,9 @@ impl NcVisual {
     /// Rendered elements will not be disrupted, but the visual can be neither
     /// decoded nor rendered any further.
     ///
-    /// *C style function: [ncvisual_destroy()][crate::ncvisual_destroy].*
+    /// *C style function: [ncvisual_destroy()][c_api::ncvisual_destroy].*
     pub fn destroy(&mut self) {
-        unsafe { crate::ncvisual_destroy(self) }
+        unsafe { c_api::ncvisual_destroy(self) }
     }
 }
 
@@ -333,10 +350,10 @@ impl NcVisual {
 impl NcVisual {
     /// Gets the specified pixel from this NcVisual.
     ///
-    /// *C style function: [ncvisual_at_yx()][crate::ncvisual_at_yx].*
+    /// *C style function: [ncvisual_at_yx()][c_api::ncvisual_at_yx].*
     pub fn at_yx(&self, y: NcDim, x: NcDim) -> NcResult<NcPixel> {
         let mut pixel = 0;
-        let res = unsafe { crate::ncvisual_at_yx(self, y as i32, x as i32, &mut pixel) };
+        let res = unsafe { c_api::ncvisual_at_yx(self, y as i32, x as i32, &mut pixel) };
         error![res, "NcVisual.at_yx()", pixel]
     }
 
@@ -344,10 +361,10 @@ impl NcVisual {
     ///
     /// Returns 0 for normal frames, and 1 to indicate EOF.
     ///
-    /// *C style function: [ncvisual_decode()][crate::ncvisual_decode].*
+    /// *C style function: [ncvisual_decode()][c_api::ncvisual_decode].*
     pub fn decode(&mut self) -> NcResult<NcIntResult> {
-        let res = unsafe { crate::ncvisual_decode(self) };
-        if res == NCRESULT_ERR {
+        let res = unsafe { c_api::ncvisual_decode(self) };
+        if res == NcIntResult::ERR {
             Err(NcError::with_msg(res, "NcVisual.decode()"))
         } else {
             Ok(res)
@@ -362,10 +379,10 @@ impl NcVisual {
     ///
     /// Returns 0 for normal frames and 1 to indicate EOF.
     ///
-    /// *C style function: [ncvisual_decode_loop()][crate::ncvisual_decode_loop].*
+    /// *C style function: [ncvisual_decode_loop()][c_api::ncvisual_decode_loop].*
     pub fn decode_loop(&mut self) -> NcResult<NcIntResult> {
-        let res = unsafe { crate::ncvisual_decode_loop(self) };
-        if res == NCRESULT_ERR {
+        let res = unsafe { c_api::ncvisual_decode_loop(self) };
+        if res == NcIntResult::ERR {
             Err(NcError::with_msg(res, "NcVisual.decode_loop()"))
         } else {
             Ok(res)
@@ -382,7 +399,7 @@ impl NcVisual {
     ///
     /// Errors on invalid blitter in `options`. Scaling is taken into consideration.
     ///
-    /// *C style function: [ncvisual_blitter_geom()][crate::ncvisual_blitter_geom].*
+    /// *C style function: [ncvisual_blitter_geom()][c_api::ncvisual_blitter_geom].*
     pub fn blitter_geom(&self, nc: &Nc, options: &NcVisualOptions) -> NcResult<NcBlitterGeometry> {
         let mut y = 0;
         let mut x = 0;
@@ -391,7 +408,7 @@ impl NcVisual {
         let mut blitter = 0;
 
         let res = unsafe {
-            crate::ncvisual_blitter_geom(
+            c_api::ncvisual_blitter_geom(
                 nc,
                 self,
                 options,
@@ -416,24 +433,24 @@ impl NcVisual {
     /// the specified scaling method.
     ///
     /// Currently, this means:
-    /// - if lacking UTF-8, [`NCBLIT_1x1`].
-    /// - otherwise, if not [`NCSCALE_STRETCH`], [`NCBLIT_2x1`].
-    /// - otherwise, if sextants are not known to be good, [`NCBLIT_2x2`].
-    /// - otherwise [`NCBLIT_3x2`], [`NCBLIT_2x2`] and [`NCBLIT_3x2`] both
-    ///   distort the original aspect ratio, thus [`NCBLIT_2x1`] is used
-    ///   outside of [`NCSCALE_STRETCH`].
+    /// - if lacking UTF-8, `NcBlitter::BLIT_1x1`.
+    /// - otherwise, if not [`NcScale::STRETCH`][NcScale#associatedconstant.STRETCH], `BLIT_2x1`.
+    /// - otherwise, if sextants are not known to be good, `NcBlitter::BLIT_2x2`.
+    /// - otherwise `NCBLIT_3x2`, `NCBLIT_2x2` and `NcBlitter::BLIT_3x2` both
+    ///   distort the original aspect ratio, thus `NCBLIT_2x1` is used
+    ///   outside of [`NcScale::STRETCH`][NcScale#associatedconstant.STRETCH].
     ///
-    /// *C style function: [ncvisual_media_defblitter()][crate::ncvisual_media_defblitter].*
+    /// *C style function: [ncvisual_media_defblitter()][c_api::ncvisual_media_defblitter].*
     pub fn media_defblitter(nc: &Nc, scale: NcScale) -> NcBlitter {
-        unsafe { crate::ncvisual_media_defblitter(nc, scale) }
+        unsafe { c_api::ncvisual_media_defblitter(nc, scale) }
     }
 
     /// Polyfills at the specified location using `rgba`.
     ///
-    /// *C style function: [ncvisual_polyfill_yx()][crate::ncvisual_polyfill_yx].*
+    /// *C style function: [ncvisual_polyfill_yx()][c_api::ncvisual_polyfill_yx].*
     pub fn polyfill_yx(&mut self, y: NcDim, x: NcDim, rgba: NcRgba) -> NcResult<()> {
         error![
-            unsafe { crate::ncvisual_polyfill_yx(self, y as i32, x as i32, rgba) },
+            unsafe { c_api::ncvisual_polyfill_yx(self, y as i32, x as i32, rgba) },
             &format!["NcVisual.polyfill_yx({}, {}, {})", y, x, rgba]
         ]
     }
@@ -445,22 +462,55 @@ impl NcVisual {
     ///
     /// See [`NcVisualOptions`].
     ///
-    /// *C style function: [ncvisual_render()][crate::ncvisual_render].*
+    /// *C style function: [ncvisual_render()][c_api::ncvisual_render].*
+    #[deprecated]
     pub fn render(&mut self, nc: &mut Nc, options: &NcVisualOptions) -> NcResult<&mut NcPlane> {
         error_ref_mut![
-            unsafe { crate::ncvisual_render(nc, self, options) },
+            unsafe { c_api::ncvisual_render(nc, self, options) },
             "NcVisual.render(Nc, &NcVisualOptions)"
         ]
     }
 
+    /// Renders the decoded frame according to the provided `options`.
+    ///
+    /// There are 3 options for choosing the the plane used for rendering:
+    /// 1. if the `options` have set the flag
+    /// [`NcVisualOptions::CHILDPLANE`][NcVisualOptions#associatedconstant.CHILDPLANE]
+    /// then there must be a plane, which will be the father of the one created.
+    /// 2. if the flag is not set and there is no plane, a new plane is created
+    ///    as root of a new pile.
+    /// 3. if the flag is not set and there is a plane, we render to it.
+    ///
+    /// A subregion of the visual can be rendered using `beg_y`, `beg_x`,
+    /// `len_y`, and `len_x`.
+    ///
+    /// It is an error to specify any region beyond the boundaries of the frame.
+    ///
+    /// Returns the (possibly newly-created) plane to which we drew.
+    ///
+    /// Pixels may not be blitted to the standard plane.
+    ///
+    /// *C style function: [ncvisual_blit()][c_api::ncvisual_blit].*
+    pub fn blit(
+        &mut self,
+        nc: &mut Nc,
+        options: Option<&NcVisualOptions>,
+    ) -> NcResult<&mut NcPlane> {
+        let options_ptr = if let Some(o) = options { o } else { null() };
+        error_ref_mut![
+            unsafe { c_api::ncvisual_blit(nc, self, options_ptr) },
+            "NcVisual.blit"
+        ]
+    }
+
     /// Resizes the visual to `cols` X `rows` pixels.
     ///
     /// This is a lossy transformation, unless the size is unchanged.
     ///
-    /// *C style function: [ncvisual_resize()][crate::ncvisual_resize].*
+    /// *C style function: [ncvisual_resize()][c_api::ncvisual_resize].*
     pub fn resize(&mut self, rows: NcDim, cols: NcDim) -> NcResult<()> {
         error![
-            unsafe { crate::ncvisual_resize(self, rows as i32, cols as i32) },
+            unsafe { c_api::ncvisual_resize(self, rows as i32, cols as i32) },
             &format!["NcVisual.resize({}, {})", rows, cols]
         ]
     }
@@ -471,10 +521,10 @@ impl NcVisual {
     /// The original color is retained.
     ///
     /// *C style function:
-    /// [ncvisual_resize_noninterpolative()][crate::ncvisual_resize_noninterpolative].*
+    /// [ncvisual_resize_noninterpolative()][c_api::ncvisual_resize_noninterpolative].*
     pub fn resize_noninterpolative(&mut self, rows: NcDim, cols: NcDim) -> NcResult<()> {
         error![
-            unsafe { crate::ncvisual_resize_noninterpolative(self, rows as i32, cols as i32) },
+            unsafe { c_api::ncvisual_resize_noninterpolative(self, rows as i32, cols as i32) },
             &format!["NcVisual.resize_noninterpolative({}, {})", cols, rows]
         ]
     }
@@ -484,20 +534,20 @@ impl NcVisual {
     /// Only M_PI/2 and -M_PI/2 are supported at the moment,
     /// but this will change. (FIXME)
     ///
-    /// *C style function: [ncvisual_rotate()][crate::ncvisual_rotate].*
+    /// *C style function: [ncvisual_rotate()][c_api::ncvisual_rotate].*
     pub fn rotate(&mut self, rads: f64) -> NcResult<()> {
         error![
-            unsafe { crate::ncvisual_rotate(self, rads) },
+            unsafe { c_api::ncvisual_rotate(self, rads) },
             &format!["NcVisual.rotate({})", rads]
         ]
     }
 
     /// Sets the specified pixel.
     ///
-    /// *C style function: [ncvisual_set_yx()][crate::ncvisual_set_yx].*
+    /// *C style function: [ncvisual_set_yx()][c_api::ncvisual_set_yx].*
     pub fn set_yx(&mut self, y: NcDim, x: NcDim, pixel: NcPixel) -> NcResult<()> {
         error![
-            unsafe { crate::ncvisual_set_yx(self, y as i32, x as i32, pixel) },
+            unsafe { c_api::ncvisual_set_yx(self, y as i32, x as i32, pixel) },
             &format!["NcVisual.set_yx({}, {}, {})", y, x, pixel]
         ]
     }
@@ -509,7 +559,7 @@ impl NcVisual {
     /// If you'd like subtitles to be decoded, provide an ncplane as the curry.
     /// If the curry is NULL, subtitles will not be displayed.
     ///
-    /// *C style function: [ncvisual_simple_streamer()][crate::ncvisual_simple_streamer].*
+    /// *C style function: [ncvisual_simple_streamer()][c_api::ncvisual_simple_streamer].*
     pub fn simple_streamer(
         &mut self,
         options: &mut NcVisualOptions,
@@ -519,7 +569,7 @@ impl NcVisual {
         if let Some(plane) = curry {
             error![
                 unsafe {
-                    crate::ncvisual_simple_streamer(
+                    c_api::ncvisual_simple_streamer(
                         self,
                         options,
                         time,
@@ -533,7 +583,7 @@ impl NcVisual {
             ]
         } else {
             error![
-                unsafe { crate::ncvisual_simple_streamer(self, options, time, null_mut()) },
+                unsafe { c_api::ncvisual_simple_streamer(self, options, time, null_mut()) },
                 &format!["NcVisual.simple_streamer({:?}, {:?}, null)", options, time]
             ]
         }
@@ -556,7 +606,7 @@ impl NcVisual {
     // /// in 300 FPS, and a `timescale` of 10 will result in 3 FPS.
     // /// It is an error to supply `timescale` less than or equal to 0.
     // ///
-    // /// *C style function: [ncvisual_streamer()][crate::ncvisual_streamer].*
+    // /// *C style function: [ncvisual_streamer()][c_api::ncvisual_streamer].*
     // //
     // // TODO: add streamcb
     // // INFO: QUESTION: is curry also optional like in simple_streamer?
@@ -574,14 +624,14 @@ impl NcVisual {
     /// If a subtitle ought be displayed at this time, returns a heap-allocated
     /// copy of the UTF8 text.
     ///
-    /// *C style function: [ncvisual_subtitle()][crate::ncvisual_subtitle].*
+    /// *C style function: [ncvisual_subtitle()][c_api::ncvisual_subtitle].*
     #[deprecated]
     pub fn subtitle(&self) -> NcResult<String> {
-        let res = unsafe { crate::ncvisual_subtitle(self) };
+        let res = unsafe { c_api::ncvisual_subtitle(self) };
         if !res.is_null() {
             Ok(rstring_free![res])
         } else {
-            Err(NcError::with_msg(NCRESULT_ERR, "NcVisual.subtitle()"))
+            Err(NcError::with_msg(NcIntResult::ERR, "NcVisual.subtitle()"))
         }
     }
 
@@ -590,44 +640,44 @@ impl NcVisual {
     /// The returned plane is bound to `parent` and contains the subtitle,
     /// which might be text or graphics (depending on the input format).
     ///
-    /// *C style function: [ncvisual_subtitle_plane()][crate::ncvisual_subtitle_plane].*
+    /// *C style function: [ncvisual_subtitle_plane()][c_api::ncvisual_subtitle_plane].*
     pub fn subtitle_plane(&self, parent: &mut NcPlane) -> NcResult<&mut NcPlane> {
-        error_ref_mut![unsafe { crate::ncvisual_subtitle_plane(parent, self) }]
+        error_ref_mut![unsafe { c_api::ncvisual_subtitle_plane(parent, self) }]
     }
 }
 
-/// # NcDirectF Constructors & destructors
-impl NcDirectF {
+/// # `NcDirectF` Constructors & destructors
+impl NcVisual {
     /// Loads media from disk, but do not yet renders it (presumably because you
     /// want to get its geometry via [ncdirectf_geom()][0], or to use the same
     /// file with [ncdirectf_render()][1] multiple times).
     ///
     /// You must destroy the result with [ncdirectf_free()][2];
     ///
-    /// [0]: crate::NcDirectF#method.ncdirectf_geom
-    /// [1]: crate::NcDirectF#method.ncdirectf_render
-    /// [2]: crate::NcDirectF#method.ncdirectf_free
+    /// [0]: NcVisual#method.ncdirectf_geom
+    /// [1]: NcVisual#method.ncdirectf_render
+    /// [2]: NcVisual#method.ncdirectf_free
     ///
-    /// *C style function: [ncdirectf_from_file()][crate::ncdirectf_from_file].*
-    pub fn ncdirectf_from_file<'a>(ncd: &mut NcDirect, file: &str) -> NcResult<&'a mut NcDirectF> {
+    /// *C style function: [ncdirectf_from_file()][c_api::ncdirectf_from_file].*
+    pub fn ncdirectf_from_file<'a>(ncd: &mut NcDirect, file: &str) -> NcResult<&'a mut NcVisual> {
         error_ref_mut![
-            unsafe { crate::ncdirectf_from_file(ncd, cstring![file]) },
-            &format!("NcDirectF::ncdirectf_from_file(ncd, {})", file)
+            unsafe { c_api::ncdirectf_from_file(ncd, cstring![file]) },
+            &format!("NcVisual::ncdirectf_from_file(ncd, {})", file)
         ]
     }
 
-    /// Frees a [`NcDirectF`] returned from [ncdirectf_from_file()][0].
+    /// Frees a [`NcVisual`] returned from [ncdirectf_from_file()][0].
     ///
-    /// [0]: crate::NcDirectF#method.ncdirectf_from_file
+    /// [0]: NcVisual#method.ncdirectf_from_file
     ///
-    /// *C style function: [ncdirectf_free()][crate::ncdirectf_free].*
+    /// *C style function: [ncdirectf_free()][c_api::ncdirectf_free].*
     pub fn ncdirectf_free(&mut self) {
-        unsafe { crate::ncdirectf_free(self) };
+        unsafe { c_api::ncdirectf_free(self) };
     }
 }
 
-/// # NcDirectF Methods
-impl NcDirectF {
+/// # `NcDirectF` Methods
+impl NcVisual {
     /// Same as [`NcDirect.render_frame()`][0], except `frame` must already have
     /// been loaded.
     ///
@@ -635,20 +685,20 @@ impl NcDirectF {
     ///
     /// [0]: NcDirect#method.render_frame
     ///
-    /// *C style function: [ncvisual_render()][crate::ncvisual_render].*
+    /// *C style function: [ncvisual_render()][c_api::ncvisual_render].*
     pub fn ncdirectf_render(
         &mut self,
         ncd: &mut NcDirect,
         options: &NcVisualOptions,
     ) -> NcResult<&mut NcPlane> {
         error_ref_mut![
-            unsafe { crate::ncdirectf_render(ncd, self, options) },
+            unsafe { c_api::ncdirectf_render(ncd, self, options) },
             "NcVisual.render()"
         ]
     }
     /// Having loaded the `frame`, get the geometry of a potential render.
     ///
-    /// *C style function: [ncdirectf_geom()][crate::ncdirectf_geom].*
+    /// *C style function: [ncdirectf_geom()][c_api::ncdirectf_geom].*
     pub fn ncdirectf_geom(
         &mut self,
         ncd: &mut NcDirect,
@@ -656,8 +706,8 @@ impl NcDirectF {
     ) -> NcResult<NcVGeom> {
         let mut geom = NcVGeom::new();
 
-        let res = unsafe { crate::ncdirectf_geom(ncd, self, options, &mut geom) };
-        error![res, "NcDirectF.ncdirectf_geom()", geom];
+        let res = unsafe { c_api::ncdirectf_geom(ncd, self, options, &mut geom) };
+        error![res, "NcVisual.ncdirectf_geom()", geom];
     }
 }
 
