@@ -1,12 +1,13 @@
 use core::ptr::null_mut;
 
 use crate::{
-    cstring, error, error_ref_mut, error_str, ncmenu_create,
+    c_api::{self, ncmenu_create},
+    cstring, error, error_ref_mut, error_str, rstring,
     widgets::{NcMenu, NcMenuOptions},
     NcInput, NcPlane, NcResult,
 };
 
-#[allow(unused_imports)]
+#[allow(unused_imports)] // for doc comments
 use crate::widgets::{NcMenuItem, NcMenuSection};
 
 /// # `NcMenu` constructors & destructors
@@ -17,16 +18,16 @@ impl NcMenu {
     /// object (as opposed to a particular plane), and are implemented as
     /// [`NcPlane`]s kept atop other NcPlanes.
     ///
-    /// *C style function: [ncmenu_create()][crate::ncmenu_create].*
+    /// *C style function: [ncmenu_create()][c_api::ncmenu_create].*
     pub fn new<'a>(plane: &mut NcPlane, options: NcMenuOptions) -> NcResult<&'a mut Self> {
         error_ref_mut![unsafe { ncmenu_create(plane, &options) }, "Creating NcMenu"]
     }
 
     /// Destroys an `NcMenu` created with [`new`][NcMenu#method.new].
     ///
-    /// *C style function: [ncmenu_destroy()][crate::ncmenu_destroy].*
+    /// *C style function: [ncmenu_destroy()][c_api::ncmenu_destroy].*
     pub fn destroy(&mut self) -> NcResult<()> {
-        error![unsafe { crate::ncmenu_destroy(self) }]
+        error![unsafe { c_api::ncmenu_destroy(self) }]
     }
 }
 
@@ -34,11 +35,11 @@ impl NcMenu {
 impl NcMenu {
     /// Disables or enables an [`NcMenuItem`].
     ///
-    /// *C style function: [ncmenu_item_set_status()][crate::ncmenu_item_set_status].*
+    /// *C style function: [ncmenu_item_set_status()][c_api::ncmenu_item_set_status].*
     pub fn item_set_status(&mut self, section: &str, item: &str, enabled: bool) -> NcResult<()> {
         error![
             unsafe {
-                crate::ncmenu_item_set_status(self, cstring![section], cstring![item], enabled)
+                c_api::ncmenu_item_set_status(self, cstring![section], cstring![item], enabled)
             },
             &format!(
                 ".item_set_status({:?}, {:?}, {:?}, {})",
@@ -50,13 +51,13 @@ impl NcMenu {
     /// Returns the [`NcMenuItem`] description
     /// corresponding to the mouse `click`.
     ///
-    /// The NcMenuItem must be on an actively unrolled section, and the click
+    /// The `NcMenuItem` must be on an actively unrolled section, and the click
     /// must be in the area of a valid item.
     ///
     /// If `ninput` is provided, and the selected item has a shortcut,
     /// it will be filled in with that shortcut.
     ///
-    /// *C style function: [ncmenu_mouse_selected()][crate::ncmenu_mouse_selected].*
+    /// *C style function: [ncmenu_mouse_selected()][c_api::ncmenu_mouse_selected].*
     pub fn mouse_selected(
         &self,
         click: NcInput,
@@ -69,7 +70,7 @@ impl NcMenu {
             ninput = null_mut();
         }
         error_str![
-            unsafe { crate::ncmenu_mouse_selected(self, &click, ninput) },
+            unsafe { c_api::ncmenu_mouse_selected(self, &click, ninput) },
             "Getting NcMenuItem description"
         ]
     }
@@ -78,18 +79,18 @@ impl NcMenu {
     ///
     /// If no section is unrolled, the first section will be unrolled.
     ///
-    /// *C style function: [ncmenu_nextitem()][crate::ncmenu_nextitem].*
+    /// *C style function: [ncmenu_nextitem()][c_api::ncmenu_nextitem].*
     pub fn nextitem(&mut self) -> NcResult<()> {
-        error![unsafe { crate::ncmenu_nextitem(self) }]
+        error![unsafe { c_api::ncmenu_nextitem(self) }]
     }
 
     /// Unrolls the next section (relative to current unrolled).
     ///
     /// If no section is unrolled, the first section will be unrolled.
     ///
-    /// *C style function: [ncmenu_nextsection()][crate::ncmenu_nextsection].*
+    /// *C style function: [ncmenu_nextsection()][c_api::ncmenu_nextsection].*
     pub fn nextsection(&mut self) -> NcResult<()> {
-        error![unsafe { crate::ncmenu_nextsection(self) }]
+        error![unsafe { c_api::ncmenu_nextsection(self) }]
     }
 
     /// Offers the `input` to this `NcMenu`.
@@ -106,17 +107,17 @@ impl NcMenu {
     /// - up or down on an unrolled menu (navigates among items)
     /// - escape on an unrolled menu (the menu is rolled up)
     ///
-    /// *C style function: [ncmenu_offer_input()][crate::ncmenu_offer_input].*
+    /// *C style function: [ncmenu_offer_input()][c_api::ncmenu_offer_input].*
     pub fn offer_input(&mut self, input: NcInput) -> bool {
-        unsafe { crate::ncmenu_offer_input(self, &input) }
+        unsafe { c_api::ncmenu_offer_input(self, &input) }
     }
 
     /// Returns the [`NcPlane`] backing this `NcMenu`.
     ///
-    /// *C style function: [ncmenu_plane()][crate::ncmenu_plane].*
+    /// *C style function: [ncmenu_plane()][c_api::ncmenu_plane].*
     pub fn plane(&mut self) -> NcResult<&NcPlane> {
         error_ref_mut![
-            unsafe { crate::ncmenu_plane(self) },
+            unsafe { c_api::ncmenu_plane(self) },
             "Getting the backing NcPlane"
         ]
     }
@@ -125,26 +126,26 @@ impl NcMenu {
     ///
     /// If no section is unrolled, the first section will be unrolled.
     ///
-    /// *C style function: [ncmenu_previtem()][crate::ncmenu_previtem].*
+    /// *C style function: [ncmenu_previtem()][c_api::ncmenu_previtem].*
     pub fn previtem(&mut self) -> NcResult<()> {
-        error![unsafe { crate::ncmenu_previtem(self) }]
+        error![unsafe { c_api::ncmenu_previtem(self) }]
     }
 
     /// Unrolls the previous section (relative to current unrolled).
     ///
     /// If no section is unrolled, the first section will be unrolled.
     ///
-    /// *C style function: [ncmenu_prevsection()][crate::ncmenu_prevsection].*
+    /// *C style function: [ncmenu_prevsection()][c_api::ncmenu_prevsection].*
     pub fn prevsection(&mut self) -> NcResult<()> {
-        error![unsafe { crate::ncmenu_prevsection(self) }]
+        error![unsafe { c_api::ncmenu_prevsection(self) }]
     }
 
     /// Rolls up any unrolled [`NcMenuSection`]
     /// and hides this `NcMenu` if using hiding.
     ///
-    /// *C style function: [ncmenu_rollup()][crate::ncmenu_rollup].*
+    /// *C style function: [ncmenu_rollup()][c_api::ncmenu_rollup].*
     pub fn rollup(&mut self) -> NcResult<()> {
-        error![unsafe { crate::ncmenu_rollup(self) }]
+        error![unsafe { c_api::ncmenu_rollup(self) }]
     }
 
     /// Returns the selected item description, if there's an unrolled section.
@@ -152,7 +153,7 @@ impl NcMenu {
     /// If `shortcut` is provided, and the selected item has a shortcut,
     /// it will be filled in with that shortcut--this can allow faster matching.
     ///
-    /// *C style function: [ncmenu_selected()][crate::ncmenu_selected].*
+    /// *C style function: [ncmenu_selected()][c_api::ncmenu_selected].*
     pub fn selected(&mut self, shortcut: Option<&mut NcInput>) -> Option<String> {
         let ninput;
         if let Some(i) = shortcut {
@@ -160,9 +161,9 @@ impl NcMenu {
         } else {
             ninput = null_mut();
         }
-        let res = unsafe { crate::ncmenu_selected(self, ninput) };
+        let res = unsafe { c_api::ncmenu_selected(self, ninput) };
         if !res.is_null() {
-            Some(unsafe { (&*res).to_string() })
+            Some(rstring![&*res].to_string())
         } else {
             None
         }
@@ -172,8 +173,8 @@ impl NcMenu {
     /// making the menu visible if it was invisible
     /// and rolling up any `NcMenuSection` that is already unrolled.
     ///
-    /// *C style function: [ncmenu_unroll()][crate::ncmenu_unroll].*
+    /// *C style function: [ncmenu_unroll()][c_api::ncmenu_unroll].*
     pub fn unroll(&mut self, sectionindex: u32) -> NcResult<()> {
-        error![unsafe { crate::ncmenu_unroll(self, sectionindex as i32) }]
+        error![unsafe { c_api::ncmenu_unroll(self, sectionindex as i32) }]
     }
 }
